@@ -2,7 +2,8 @@ package Search::Indexer;
 
 use strict;
 use warnings; 
-# no warnings 'uninitialized'; ## CHECK IF NEEDED OR NOT
+no warnings 'uninitialized';
+
 use Carp;
 use BerkeleyDB;
 use locale;
@@ -12,7 +13,7 @@ use List::MoreUtils qw/uniq/;
 # TODO : experiment with bit vectors (cf vec() and pack "b*" for combining 
 #        result sets
 
-our $VERSION = "0.77";
+our $VERSION = "0.78";
 
 =head1 NAME
 
@@ -27,7 +28,7 @@ Search::Indexer - full-text indexer
   }
 
   my $result = $ix->search('+word -excludedWord +"exact phrase"');
-  my @docIds = keys @{$result->{scores}};
+  my @docIds = keys %{$result->{scores}};
   my $killedWords = join ", ", @{$result->{killedWords}};
   print scalar(@docIds), " documents found\n", ;
   print "words $killedWords were ignored during the search\n" if $killedWords;
